@@ -96,8 +96,8 @@ class SegmentMappingSim(MetadynamicSimulation):
                 print("""Warning, Distance CV upper bound set to less than unbound distance, replacing
                 unbound_distance with max distance CV, new value is {}""".format(cv[4]))
 
-        if self.CV_list[0][0] not in ['Distance', 'Weighted Distances']:
-            raise ValueError('Segment Map Sim without distance or weighted distances not yet supported')
+        # if self.CV_list[0][0] not in ['Distance', 'Weighted Distances']:
+        #     raise ValueError('Segment Map Sim without distance or weighted distances not yet supported')
 
         if self.scan_bias < self.prod_bias:
             print('WARNING: scan bias should be high (40-50) and prod bias should be low (5-10)')
